@@ -3,7 +3,7 @@ package Meow;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('Meow', $VERSION);
@@ -18,7 +18,7 @@ Meow - Object ฅ^•ﻌ•^ฅ Orientation
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -39,14 +39,15 @@ This module is experimental. Many basic features do not yet exist.
 
 ...
 
-	my $cat = Cat->new();
-
-	$cat->name("Simba");
-	$cat->age(10);
+	my $cat = Cat->new(
+		name => 'Simba',
+		age => 10
+	);
 
 	$cat->name; # Simba;
 	$cat->age; # 10;
 	
+	$cat->age(11);
 
 =head1 AUTHOR
 
